==> aroundme_0_6_2.tar.tgz: aroundme_0_6_2/aroundme/template/barnraiser_01/my_view.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
?>

<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_network'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
			<p>
				<b><?php echo $lang['txt_degree1'];?></b><br />
			</p>
			
			<p>
				<a href="sn_list.php?relation=1"><?php echo $lang['href_view_relations'];?></a><br />
				<a href="sn_invite.php"><?php echo $lang['href_invite_relations'];?></a><br />
			</p>
			
			<p>
				<b><?php echo $lang['txt_network'];?></b><br />
			</p>
			
			<p>
				<a href="sn_list.php"><?php echo $lang['href_view_directory'];?></a><br />
			</p>
			
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_blog'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
			<p>
				<?php echo $lang['txt_blog_intro'];?><br />
			</p>
			
			<p>
				<b><?php echo $lang['txt_blog'];?></b><br />
			</p>
			
			<p>
				<a href="blg_view.php?view=my"><?php echo $lang['href_view_blog'];?></a><br />
				<a href="blg_edit.php"><?php echo $lang['href_add_blog_entry'];?></a><br />
			</p>
			
			<p>
				<b><?php echo $lang['txt_blog_comments'];?></b><br />
			</p>
			
			<?php
			if (isset($blog_comment)) {
			?>
				<p>
					<b><?php echo $lang['txt_latest_comment'];?></b><br />
				</p>
				
				<p>
					<?php echo $this->date->formatDate($blog_comment['comment_create_datetime'], 1);?>: 
					<a href="sn_profile.php?user_id=<?php echo $blog_comment['user_id'];?>"><?php echo $blog_comment['profile_nic'];?></a><br />
					<?php echo $blog_comment['comment_body'];?><br />
				</p>
			<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

==> aroundme_0_6_6.tar.tgz: aroundme_0_6_6/aroundme/template/barnraiser_01/my_view.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
?>

<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_network'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
			<p>
				<b><?php echo $lang['txt_degree1'];?></b><br />
			</p>
			
			<p>
				<a href="sn_list.php?relation=1"><?php echo $lang['href_view_relations'];?></a><br />
				<a href="sn_invite.php"><?php echo $lang['href_invite_relations'];?></a><br />
			</p>
			
			<p>
				<b><?php echo $lang['txt_network'];?></b><br />
			</p>
			
			<p>
				<a href="sn_list.php"><?php echo $lang['href_view_directory'];?></a><br />
			</p>
			
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_blog'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
			<p>
				<?php echo $lang['txt_blog_intro'];?><br />
			</p>
			
			<p>
				<b><?php echo $lang['txt_blog'];?></b><br />
			</p>
			
			<p>
				<a href="blg_view.php?view=my_blog"><?php echo $lang['href_view_blog'];?></a><br />
				<a href="blg_edit.php"><?php echo $lang['href_add_blog_entry'];?></a><br />
			</p>
			
			<p>
				<b><?php echo $lang['txt_blog_comments'];?></b><br />
			</p>
			
			<?php
			if (isset($blog_comment)) {
			?>
				<p>
					<b><?php echo $lang['txt_latest_comment'];?></b><br />
				</p>
				
				<p>
					<?php echo $this->date->formatDate($blog_comment['comment_create_datetime'], 1);?>: 
					<a href="sn_profile.php?user_id=<?php echo $blog_comment['user_id'];?>"><?php echo $blog_comment['profile_nic'];?></a><br />
					<?php echo $blog_comment['comment_body'];?><br />
				</p>
			<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>
